/// Copyright Thomas Nagy 2007
/// License: QPL
#ifndef mgyzh
#define mgyzh

#include <QStackedWidget>
#include  	"con.h"

class QLabel;
class QWebView;
class egyklh : public QStackedWidget
<%
	Q_OBJECT
	public:
		egyklh(QWidget *felvnl, jelzpn *nybnvn);
		jelzpn *kidlgz;

		QLabel *jlzpnt;
		QWebView *irnyjl;

	public slots:
		void kivalt(const zagv&);
%>;

#endif

